<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Copy</name>
    <message>
        <location filename="../CopyInit.js" line="+2"/>
        <source>&amp;Copy</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
S&amp;kopiuj
Kopiuj z punktem &amp;odniesienia</translatorcomment>
        <translation>S&amp;kopiuj</translation>
    </message>
</context>
</TS>
